==> wevue-1.2.28.tgz: package/vue/src/main-admin.js <==
import Vue from 'vue'
import VueRouter from 'vue-router'
import Vuex from 'vuex'

let path = require('path')

const appConf = require('./app-admin.json')

let sdk = require('wevue-tools')

let tools = sdk.tools

window.wx=sdk.wx;
window.Page = sdk.Page;
window.App = sdk.App;
window.getApp = App.getApp;
window.PVAPP = {};
window.PVCI = {};

window.PVBI = {};//backend实例

window.__wxPageOptionsJar = {}

window.__wxBackendOptions = {}

window.__wxPageOptions = {}
window.__wxAppOptions = {}
window.PagePath = '/';

Vue.config.silent = false
Vue.config.errorHandler = function (err, vm) {
  // handle error
  console.warn(err);
}
Vue.use(VueRouter)
Vue.use(Vuex)
let AppView = require('promise?bluebird!./layouts/App-admin.vue')

require('layouts/RegPlugins-admin.vue')
const routes = tools.getAppRouters(appConf)

const store = new Vuex.Store({
    state: {},
    mutations: {
        setData(state,payload){
            if(payload.backend){
                Object.assign(state.__pv_backend,payload)
            }else{
                Object.assign(state[PagePath.replace(/\//g,'_')],payload)
            }
        }
    },
    actions: {
        setData(ctx,params){
            if('object'!==typeof params){
                return new Error('setData参数必须是一个state对象')
            }

            ctx.commit('setData',params)
        }
    },
    modules:{}
})

const router = new VueRouter({
  routes
})
router.beforeEach((to, from, next) => {
    PagePath = to.path
    var fromStore = ''

    if(from.path!=='/'){
        if(PVAPP){
            if(PVAPP.$store){
                fromStore = from.path.replace(/\//g,'_')
                if(to.path!==from.path){
                    PVAPP.$store.unregisterModule(fromStore)
                }
                __wxPageOptions = __wxPageOptionsJar[PagePath]
            }
        }
    }
    next()
})
router.afterEach(route => {
    if(PVCI._uid){

        tools.pageOnShow(PVCI)
    }
})


require('./app-admin.js')  //执行pc版   app.js

App.__initApp(function(){
    new Vue({
        store,
        router,
        render:h=>h(AppView),
        created:function(){
            PVAPP = this

            tools.appOnLoad(this)

        },
        mounted:function(){
            tools.appOnShow(this)
        },
        destroyed:function(){
            tools.appOnHide(this)
        }
    }).$mount('#app')
})

==> wevue-1.3.5.tgz: package/vue/src/main-admin.js <==
import Vue from 'vue'
import VueRouter from 'vue-router'
import Vuex from 'vuex'

let path = require('path')

const appConf = require('./app-admin.json')

let sdk = require('wevue-tools')

let tools = sdk.tools

window.wx=sdk.wx;
window.Page = sdk.Page;
window.App = sdk.App;
window.getApp = App.getApp;
window.PVAPP = {};
window.PVCI = {};

window.PVBI = {};//backend实例

window.__wxPageOptionsJar = {}

window.__wxBackendOptions = {}

window.__wxPageOptions = {}
window.__wxAppOptions = {}
window.PagePath = '/';

Vue.config.silent = false
Vue.config.errorHandler = function (err, vm) {
  // handle error
  console.warn(err);
}
Vue.use(VueRouter)
Vue.use(Vuex)
let AppView = require('promise?bluebird!./layouts/App-admin.vue')

require('layouts/RegPlugins-admin.vue')
const routes = tools.getAppRouters(appConf)

const store = new Vuex.Store({
    state: {},
    mutations: {
        setData(state,payload){
            if(payload.backend){
                return Object.assign(state.__pv_backend,payload)
            }else{
                return Object.assign(state[PagePath.replace(/\//g,'_')],payload)
            }
        }
    },
    actions: {
        setData(ctx,params){
            if('object'!==typeof params){
                return new Error('setData参数必须是一个state对象')
            }

            return ctx.commit('setData',params)
        }
    },
    modules:{}
})

const router = new VueRouter({
  routes
})
router.beforeEach((to, from, next) => {
    PagePath = to.path
    var fromStore = ''

    if(from.path!=='/'){
        if(PVAPP){
            if(PVAPP.$store){
                fromStore = from.path.replace(/\//g,'_')
                if(to.path!==from.path){
                    PVAPP.$store.unregisterModule(fromStore)
                }
                __wxPageOptions = __wxPageOptionsJar[PagePath]
            }
        }
    }
    next()
})
router.afterEach(route => {
    if(PVCI._uid){

        tools.pageOnShow(PVCI)
    }
})


require('./app-admin.js')  //执行pc版   app.js

App.__initApp(function(){
    new Vue({
        store,
        router,
        render:h=>h(AppView),
        created:function(){
            PVAPP = this

            tools.appOnLoad(this)

        },
        mounted:function(){
            tools.appOnShow(this)
        },
        destroyed:function(){
            tools.appOnHide(this)
        }
    }).$mount('#app')
})
